==> ideaIC-212.5457.46-sources.jar: com/jetbrains/packagesearch/intellij/plugin/ui/toolwindow/panels/management/packages/columns/renderers/PackageScopeTableCellRenderer.kt <==
package com.jetbrains.packagesearch.intellij.plugin.ui.toolwindow.panels.management.packages.columns.renderers

import com.intellij.icons.AllIcons
import com.intellij.openapi.util.NlsSafe
import com.intellij.ui.components.JBComboBoxLabel
import com.jetbrains.packagesearch.intellij.plugin.ui.PackageSearchUI
import com.jetbrains.packagesearch.intellij.plugin.ui.toolwindow.models.PackageScope
import com.jetbrains.packagesearch.intellij.plugin.ui.toolwindow.models.UiPackageModel
import com.jetbrains.packagesearch.intellij.plugin.ui.toolwindow.panels.management.packages.columns.colors
import net.miginfocom.swing.MigLayout
import javax.swing.JPanel
import javax.swing.JTable
import javax.swing.table.TableCellRenderer

internal object PackageScopeTableCellRenderer : TableCellRenderer {

    override fun getTableCellRendererComponent(
        table: JTable,
        value: Any,
        isSelected: Boolean,
        hasFocus: Boolean,
        row: Int,
        column: Int
    ) = JPanel(MigLayout("al left center, insets 0 8 0 0")).apply {
        table.colors.applyTo(this, isSelected)

        val bgColor = if (!isSelected && value is UiPackageModel.SearchResult) {
            PackageSearchUI.ListRowHighlightBackground
        } else {
            background
        }

        background = bgColor

        val jbComboBoxLabel = JBComboBoxLabel().apply {
            table.colors.applyTo(this, isSelected)
            background = bgColor
            icon = AllIcons.General.LinkDropTriangle

            text = when (value) {
                is UiPackageModel.Installed -> scopesMessage(value.declaredScopes, value.defaultScope)
                is UiPackageModel.SearchResult -> value.selectedScope.displayName
                else -> throw IllegalArgumentException("The value is expected to be a ScopeViewModel, but wasn't.")
            }
        }
        add(jbComboBoxLabel)
    }

    @NlsSafe
    private fun scopesMessage(installedScopes: List<PackageScope>, defaultScope: PackageScope): String {
        if (installedScopes.isEmpty()) return defaultScope.displayName

        return installedScopes.joinToString { it.displayName }
    }
}

==> ideaIC-213.7172.25-sources.jar: com/jetbrains/packagesearch/intellij/plugin/ui/toolwindow/panels/management/packages/columns/renderers/PackageScopeTableCellRenderer.kt <==
package com.jetbrains.packagesearch.intellij.plugin.ui.toolwindow.panels.management.packages.columns.renderers

import com.intellij.icons.AllIcons
import com.intellij.openapi.util.NlsSafe
import com.intellij.ui.components.JBComboBoxLabel
import com.jetbrains.packagesearch.intellij.plugin.ui.PackageSearchUI
import com.jetbrains.packagesearch.intellij.plugin.ui.toolwindow.models.PackageScope
import com.jetbrains.packagesearch.intellij.plugin.ui.toolwindow.panels.management.packages.PackagesTableItem
import com.jetbrains.packagesearch.intellij.plugin.ui.toolwindow.panels.management.packages.columns.colors
import net.miginfocom.swing.MigLayout
import javax.swing.JPanel
import javax.swing.JTable
import javax.swing.table.TableCellRenderer

internal object PackageScopeTableCellRenderer : TableCellRenderer {

    override fun getTableCellRendererComponent(
        table: JTable,
        value: Any,
        isSelected: Boolean,
        hasFocus: Boolean,
        row: Int,
        column: Int
    ) = JPanel(MigLayout("al left center, insets 0 8 0 0")).apply {
        table.colors.applyTo(this, isSelected)

        val bgColor = if (!isSelected && value is PackagesTableItem.InstallablePackage) {
            PackageSearchUI.ListRowHighlightBackground
        } else {
            background
        }

        background = bgColor

        val jbComboBoxLabel = JBComboBoxLabel().apply {
            table.colors.applyTo(this, isSelected)
            background = bgColor
            icon = AllIcons.General.LinkDropTriangle

            text = when (value) {
                is PackagesTableItem<*> -> value.uiPackageModel.selectedScope.displayName
                else -> throw IllegalArgumentException("The value is expected to be a PackagesTableItem, but wasn't.")
            }
        }
        add(jbComboBoxLabel)
    }

    @NlsSafe
    private fun scopesMessage(installedScopes: List<PackageScope>, defaultScope: PackageScope): String {
        if (installedScopes.isEmpty()) return defaultScope.displayName

        return installedScopes.joinToString { it.displayName }
    }
}
